# Configuration of the Apptio Connector
### On this page
  * [Before You Start](https://help.sap.com/docs/leanix/ea/configuration-of-apptio-connector#before-you-start)
  * [Apptio Configuration JSON](https://help.sap.com/docs/leanix/ea/configuration-of-apptio-connector#apptio-configuration-json)
  * [General Configuration parts](https://help.sap.com/docs/leanix/ea/configuration-of-apptio-connector#general-configuration-parts)
  * [apptioConnectionConfig](https://help.sap.com/docs/leanix/ea/configuration-of-apptio-connector#apptioconnectionconfig)
  * [Read data from Apptio (download)](https://help.sap.com/docs/leanix/ea/configuration-of-apptio-connector#read-data-from-apptio-\(download\))
  * [Write data to Apptio (upload)](https://help.sap.com/docs/leanix/ea/configuration-of-apptio-connector#write-data-to-apptio-\(upload\))


Set up the Apptio connector, configure field mapping and synchronization settings to enrich the SAP LeanIX workspace with up-to-date cost information.
